summaryrefslogtreecommitdiffstats
path: root/c++/src/H5LcreatProp.h
diff options
context:
space:
mode:
authorBinh-Minh Ribler <bmribler@hdfgroup.org>2019-03-20 19:07:40 (GMT)
committerBinh-Minh Ribler <bmribler@hdfgroup.org>2019-03-20 19:07:40 (GMT)
commit222346f3732ba3bfb007da410e1b808be129aaaf (patch)
tree061d33723552465bbb3b672bfff10e4fe6bc2b96 /c++/src/H5LcreatProp.h
parent7add52ff4f2443357648d53d52add274d1b18b5f (diff)
parent604b67df19a164824b74fba0aa5e489b5a64d1ae (diff)
downloadhdf5-222346f3732ba3bfb007da410e1b808be129aaaf.zip
hdf5-222346f3732ba3bfb007da410e1b808be129aaaf.tar.gz
hdf5-222346f3732ba3bfb007da410e1b808be129aaaf.tar.bz2
Merge branch 'develop' of https://bitbucket.hdfgroup.org/scm/~bmribler/hdf5_bmr_fixbug into develop
Diffstat (limited to 'c++/src/H5LcreatProp.h')
-rw-r--r--c++/src/H5LcreatProp.h11
1 files changed, 4 insertions, 7 deletions
diff --git a/c++/src/H5LcreatProp.h b/c++/src/H5LcreatProp.h
index 12cb479..f6e10bf 100644
--- a/c++/src/H5LcreatProp.h
+++ b/c++/src/H5LcreatProp.h
@@ -12,9 +12,6 @@
* help@hdfgroup.org. *
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-// Class LinkCreatPropList represents the HDF5 file access property list and
-// inherits from DataType.
-
#ifndef __H5LinkCreatPropList_H
#define __H5LinkCreatPropList_H
@@ -22,15 +19,15 @@ namespace H5 {
/*! \class LinkCreatPropList
\brief Class LinkCreatPropList inherits from PropList and provides
- wrappers for the HDF5 file access property list.
+ wrappers for the HDF5 link creation property list.
*/
// Inheritance: PropList -> IdComponent
class H5_DLLCPP LinkCreatPropList : public PropList {
public:
///\brief Default file access property list.
static const LinkCreatPropList& DEFAULT;
// Creates a file access property list.
LinkCreatPropList();
///\brief Returns this class name.
@@ -39,7 +36,7 @@ class H5_DLLCPP LinkCreatPropList : public PropList {
// Copy constructor: same as the original LinkCreatPropList.
LinkCreatPropList(const LinkCreatPropList& original);
// Creates a copy of an existing file access property list
// using the property list id.
LinkCreatPropList (const hid_t plist_id);
@@ -22,15 +19,15 @@ namespace H5 {
class H5_DLLCPP LinkCreatPropList : public PropList {
public:
- ///\brief Default file access property list.
+ ///\brief Default link creation property list.
static const LinkCreatPropList& DEFAULT;
@@ -22,15 +19,15 @@ namespace H5 {
static const LinkCreatPropList& DEFAULT;
- // Creates a file access property list.
+ // Creates a link creation property list.
LinkCreatPropList();
///\brief Returns this class name.
@@ -39,7 +36,7 @@ class H5_DLLCPP LinkCreatPropList : public PropList {
// Copy constructor: same as the original LinkCreatPropList.
LinkCreatPropList(const LinkCreatPropList& original);
- // Creates a copy of an existing file access property list
+ // Creates a copy of an existing link creation property list
// using the property list id.
LinkCreatPropList (const hid_t plist_id);